# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/vault/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/vault/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as dydxprotocol_dot_subaccounts_dot_subaccount__pb2
from v4_proto.dydxprotocol.vault import params_pb2 as dydxprotocol_dot_vault_dot_params__pb2
from v4_proto.dydxprotocol.vault import share_pb2 as dydxprotocol_dot_vault_dot_share__pb2
from v4_proto.dydxprotocol.vault import vault_pb2 as dydxprotocol_dot_vault_dot_vault__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x64ydxprotocol/vault/query.proto\x12\x12\x64ydxprotocol.vault\x1a\x19\x63osmos_proto/cosmos.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a)dydxprotocol/subaccounts/subaccount.proto\x1a\x1f\x64ydxprotocol/vault/params.proto\x1a\x1e\x64ydxprotocol/vault/share.proto\x1a\x1e\x64ydxprotocol/vault/vault.proto\"\x14\n\x12QueryParamsRequest\"\xa1\x01\n\x13QueryParamsResponse\x12G\n\x16\x64\x65\x66\x61ult_quoting_params\x18\x01 \x01(\x0b\x32!.dydxprotocol.vault.QuotingParamsB\x04\xc8\xde\x1f\x00\x12\x41\n\x0foperator_params\x18\x02 \x01(\x0b\x32\".dydxprotocol.vault.OperatorParamsB\x04\xc8\xde\x1f\x00\"P\n\x11QueryVaultRequest\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.dydxprotocol.vault.VaultType\x12\x0e\n\x06number\x18\x02 \x01(\r\"\xa2\x03\n\x12QueryVaultResponse\x12\x33\n\x08vault_id\x18\x01 \x01(\x0b\x32\x1b.dydxprotocol.vault.VaultIdB\x04\xc8\xde\x1f\x00\x12\x43\n\rsubaccount_id\x18\x02 \x01(\x0b\x32&.dydxprotocol.subaccounts.SubaccountIdB\x04\xc8\xde\x1f\x00\x12X\n\x06\x65quity\x18\x03 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12[\n\tinventory\x18\x04 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12;\n\x0cvault_params\x18\x05 \x01(\x0b\x32\x1f.dydxprotocol.vault.VaultParamsB\x04\xc8\xde\x1f\x00\x12\x1e\n\x16most_recent_client_ids\x18\x06 \x03(\r\"S\n\x15QueryAllVaultsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x8d\x01\n\x16QueryAllVaultsResponse\x12\x36\n\x06vaults\x18\x01 \x03(\x0b\x32&.dydxprotocol.vault.QueryVaultResponse\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\"\n QueryMegavaultTotalSharesRequest\"X\n!QueryMegavaultTotalSharesResponse\x12\x33\n\x0ctotal_shares\x18\x01 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumShares\"M\n QueryMegavaultOwnerSharesRequest\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"\x82\x03\n!QueryMegavaultOwnerSharesResponse\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x06shares\x18\x02 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumSharesB\x04\xc8\xde\x1f\x00\x12<\n\rshare_unlocks\x18\x03 \x03(\x0b\x32\x1f.dydxprotocol.vault.ShareUnlockB\x04\xc8\xde\x1f\x00\x12X\n\x06\x65quity\x18\x04 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12\x65\n\x13withdrawable_equity\x18\x05 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\"a\n#QueryMegavaultAllOwnerSharesRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x99\x01\n$QueryMegavaultAllOwnerSharesResponse\x12\x34\n\x0cowner_shares\x18\x01 \x03(\x0b\x32\x1e.dydxprotocol.vault.OwnerShare\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"V\n\x17QueryVaultParamsRequest\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.dydxprotocol.vault.VaultType\x12\x0e\n\x06number\x18\x02 \x01(\r\"\x8c\x01\n\x18QueryVaultParamsResponse\x12\x33\n\x08vault_id\x18\x01 \x01(\x0b\x32\x1b.dydxprotocol.vault.VaultIdB\x04\xc8\xde\x1f\x00\x12;\n\x0cvault_params\x18\x02 \x01(\x0b\x32\x1f.dydxprotocol.vault.VaultParamsB\x04\xc8\xde\x1f\x00\"f\n#QueryMegavaultWithdrawalInfoRequest\x12?\n\x12shares_to_withdraw\x18\x01 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumSharesB\x04\xc8\xde\x1f\x00\"\xf1\x02\n$QueryMegavaultWithdrawalInfoResponse\x12?\n\x12shares_to_withdraw\x18\x01 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumSharesB\x04\xc8\xde\x1f\x00\x12i\n\x17\x65xpected_quote_quantums\x18\x02 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12\x62\n\x10megavault_equity\x18\x03 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12\x39\n\x0ctotal_shares\x18\x04 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumSharesB\x04\xc8\xde\x1f\x00\x32\xc7\n\n\x05Query\x12}\n\x06Params\x12&.dydxprotocol.vault.QueryParamsRequest\x1a\'.dydxprotocol.vault.QueryParamsResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/dydxprotocol/vault/params\x12\x89\x01\n\x05Vault\x12%.dydxprotocol.vault.QueryVaultRequest\x1a&.dydxprotocol.vault.QueryVaultResponse\"1\x82\xd3\xe4\x93\x02+\x12)/dydxprotocol/vault/vault/{type}/{number}\x12\x85\x01\n\tAllVaults\x12).dydxprotocol.vault.QueryAllVaultsRequest\x1a*.dydxprotocol.vault.QueryAllVaultsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/dydxprotocol/vault/vault\x12\xb7\x01\n\x14MegavaultTotalShares\x12\x34.dydxprotocol.vault.QueryMegavaultTotalSharesRequest\x1a\x35.dydxprotocol.vault.QueryMegavaultTotalSharesResponse\"2\x82\xd3\xe4\x93\x02,\x12*/dydxprotocol/vault/megavault/total_shares\x12\xc1\x01\n\x14MegavaultOwnerShares\x12\x34.dydxprotocol.vault.QueryMegavaultOwnerSharesRequest\x1a\x35.dydxprotocol.vault.QueryMegavaultOwnerSharesResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/dydxprotocol/vault/megavault/owner_shares/{address}\x12\xc4\x01\n\x17MegavaultAllOwnerShares\x12\x37.dydxprotocol.vault.QueryMegavaultAllOwnerSharesRequest\x1a\x38.dydxprotocol.vault.QueryMegavaultAllOwnerSharesResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./dydxprotocol/vault/megavault/all_owner_shares\x12\x9c\x01\n\x0bVaultParams\x12+.dydxprotocol.vault.QueryVaultParamsRequest\x1a,.dydxprotocol.vault.QueryVaultParamsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/dydxprotocol/vault/params/{type}/{number}\x12\xc6\x01\n\x17MegavaultWithdrawalInfo\x12\x37.dydxprotocol.vault.QueryMegavaultWithdrawalInfoRequest\x1a\x38.dydxprotocol.vault.QueryMegavaultWithdrawalInfoResponse\"8\x82\xd3\xe4\x93\x02\x32\"-/dydxprotocol/vault/megavault/withdrawal_info:\x01*B9Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vault.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['default_quoting_params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['default_quoting_params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['operator_params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['operator_params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['vault_id']._loaded_options = None
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['vault_id']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['subaccount_id']._loaded_options = None
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['subaccount_id']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['equity']._loaded_options = None
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['equity']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['inventory']._loaded_options = None
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['inventory']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['vault_params']._loaded_options = None
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['vault_params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYMEGAVAULTOWNERSHARESREQUEST'].fields_by_name['address']._loaded_options = None
  _globals['_QUERYMEGAVAULTOWNERSHARESREQUEST'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYMEGAVAULTOWNERSHARESRESPONSE'].fields_by_name['address']._loaded_options = None
  _globals['_QUERYMEGAVAULTOWNERSHARESRESPONSE'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYMEGAVAULTOWNERSHARESRESPONSE'].fields_by_name['shares']._loaded_options = None
  _globals['_QUERYMEGAVAULTOWNERSHARESRESPONSE'].fields_by_name['shares']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYMEGAVAULTOWNERSHARESRESPONSE'].fields_by_name['share_unlocks']._loaded_options = None
  _globals['_QUERYMEGAVAULTOWNERSHARESRESPONSE'].fields_by_name['share_unlocks']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYMEGAVAULTOWNERSHARESRESPONSE'].fields_by_name['equity']._loaded_options = None
  _globals['_QUERYMEGAVAULTOWNERSHARESRESPONSE'].fields_by_name['equity']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_QUERYMEGAVAULTOWNERSHARESRESPONSE'].fields_by_name['withdrawable_equity']._loaded_options = None
  _globals['_QUERYMEGAVAULTOWNERSHARESRESPONSE'].fields_by_name['withdrawable_equity']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_QUERYVAULTPARAMSRESPONSE'].fields_by_name['vault_id']._loaded_options = None
  _globals['_QUERYVAULTPARAMSRESPONSE'].fields_by_name['vault_id']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYVAULTPARAMSRESPONSE'].fields_by_name['vault_params']._loaded_options = None
  _globals['_QUERYVAULTPARAMSRESPONSE'].fields_by_name['vault_params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYMEGAVAULTWITHDRAWALINFOREQUEST'].fields_by_name['shares_to_withdraw']._loaded_options = None
  _globals['_QUERYMEGAVAULTWITHDRAWALINFOREQUEST'].fields_by_name['shares_to_withdraw']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYMEGAVAULTWITHDRAWALINFORESPONSE'].fields_by_name['shares_to_withdraw']._loaded_options = None
  _globals['_QUERYMEGAVAULTWITHDRAWALINFORESPONSE'].fields_by_name['shares_to_withdraw']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYMEGAVAULTWITHDRAWALINFORESPONSE'].fields_by_name['expected_quote_quantums']._loaded_options = None
  _globals['_QUERYMEGAVAULTWITHDRAWALINFORESPONSE'].fields_by_name['expected_quote_quantums']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_QUERYMEGAVAULTWITHDRAWALINFORESPONSE'].fields_by_name['megavault_equity']._loaded_options = None
  _globals['_QUERYMEGAVAULTWITHDRAWALINFORESPONSE'].fields_by_name['megavault_equity']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_QUERYMEGAVAULTWITHDRAWALINFORESPONSE'].fields_by_name['total_shares']._loaded_options = None
  _globals['_QUERYMEGAVAULTWITHDRAWALINFORESPONSE'].fields_by_name['total_shares']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\034\022\032/dydxprotocol/vault/params'
  _globals['_QUERY'].methods_by_name['Vault']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Vault']._serialized_options = b'\202\323\344\223\002+\022)/dydxprotocol/vault/vault/{type}/{number}'
  _globals['_QUERY'].methods_by_name['AllVaults']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AllVaults']._serialized_options = b'\202\323\344\223\002\033\022\031/dydxprotocol/vault/vault'
  _globals['_QUERY'].methods_by_name['MegavaultTotalShares']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MegavaultTotalShares']._serialized_options = b'\202\323\344\223\002,\022*/dydxprotocol/vault/megavault/total_shares'
  _globals['_QUERY'].methods_by_name['MegavaultOwnerShares']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MegavaultOwnerShares']._serialized_options = b'\202\323\344\223\0026\0224/dydxprotocol/vault/megavault/owner_shares/{address}'
  _globals['_QUERY'].methods_by_name['MegavaultAllOwnerShares']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MegavaultAllOwnerShares']._serialized_options = b'\202\323\344\223\0020\022./dydxprotocol/vault/megavault/all_owner_shares'
  _globals['_QUERY'].methods_by_name['VaultParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['VaultParams']._serialized_options = b'\202\323\344\223\002,\022*/dydxprotocol/vault/params/{type}/{number}'
  _globals['_QUERY'].methods_by_name['MegavaultWithdrawalInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MegavaultWithdrawalInfo']._serialized_options = b'\202\323\344\223\0022\"-/dydxprotocol/vault/megavault/withdrawal_info:\001*'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=317
  _globals['_QUERYPARAMSREQUEST']._serialized_end=337
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=340
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=501
  _globals['_QUERYVAULTREQUEST']._serialized_start=503
  _globals['_QUERYVAULTREQUEST']._serialized_end=583
  _globals['_QUERYVAULTRESPONSE']._serialized_start=586
  _globals['_QUERYVAULTRESPONSE']._serialized_end=1004
  _globals['_QUERYALLVAULTSREQUEST']._serialized_start=1006
  _globals['_QUERYALLVAULTSREQUEST']._serialized_end=1089
  _globals['_QUERYALLVAULTSRESPONSE']._serialized_start=1092
  _globals['_QUERYALLVAULTSRESPONSE']._serialized_end=1233
  _globals['_QUERYMEGAVAULTTOTALSHARESREQUEST']._serialized_start=1235
  _globals['_QUERYMEGAVAULTTOTALSHARESREQUEST']._serialized_end=1269
  _globals['_QUERYMEGAVAULTTOTALSHARESRESPONSE']._serialized_start=1271
  _globals['_QUERYMEGAVAULTTOTALSHARESRESPONSE']._serialized_end=1359
  _globals['_QUERYMEGAVAULTOWNERSHARESREQUEST']._serialized_start=1361
  _globals['_QUERYMEGAVAULTOWNERSHARESREQUEST']._serialized_end=1438
  _globals['_QUERYMEGAVAULTOWNERSHARESRESPONSE']._serialized_start=1441
  _globals['_QUERYMEGAVAULTOWNERSHARESRESPONSE']._serialized_end=1827
  _globals['_QUERYMEGAVAULTALLOWNERSHARESREQUEST']._serialized_start=1829
  _globals['_QUERYMEGAVAULTALLOWNERSHARESREQUEST']._serialized_end=1926
  _globals['_QUERYMEGAVAULTALLOWNERSHARESRESPONSE']._serialized_start=1929
  _globals['_QUERYMEGAVAULTALLOWNERSHARESRESPONSE']._serialized_end=2082
  _globals['_QUERYVAULTPARAMSREQUEST']._serialized_start=2084
  _globals['_QUERYVAULTPARAMSREQUEST']._serialized_end=2170
  _globals['_QUERYVAULTPARAMSRESPONSE']._serialized_start=2173
  _globals['_QUERYVAULTPARAMSRESPONSE']._serialized_end=2313
  _globals['_QUERYMEGAVAULTWITHDRAWALINFOREQUEST']._serialized_start=2315
  _globals['_QUERYMEGAVAULTWITHDRAWALINFOREQUEST']._serialized_end=2417
  _globals['_QUERYMEGAVAULTWITHDRAWALINFORESPONSE']._serialized_start=2420
  _globals['_QUERYMEGAVAULTWITHDRAWALINFORESPONSE']._serialized_end=2789
  _globals['_QUERY']._serialized_start=2792
  _globals['_QUERY']._serialized_end=4143
# @@protoc_insertion_point(module_scope)



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class RewardShare(_message.Message):
    __slots__ = ("address", "weight")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    address: str
    weight: bytes
    def __init__(self, address: _Optional[str] = ..., weight: _Optional[bytes] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.tendermint.abci import types_pb2 as _types_pb2
from v4_proto.tendermint.types import block_pb2 as _block_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TxResponse(_message.Message):
    __slots__ = ("height", "txhash", "codespace", "code", "data", "raw_log", "logs", "info", "gas_wanted", "gas_used", "tx", "timestamp", "events")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TXHASH_FIELD_NUMBER: _ClassVar[int]
    CODESPACE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    RAW_LOG_FIELD_NUMBER: _ClassVar[int]
    LOGS_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    GAS_WANTED_FIELD_NUMBER: _ClassVar[int]
    GAS_USED_FIELD_NUMBER: _ClassVar[int]
    TX_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    height: int
    txhash: str
    codespace: str
    code: int
    data: str
    raw_log: str
    logs: _containers.RepeatedCompositeFieldContainer[ABCIMessageLog]
    info: str
    gas_wanted: int
    gas_used: int
    tx: _any_pb2.Any
    timestamp: str
    events: _containers.RepeatedCompositeFieldContainer[_types_pb2.Event]
    def __init__(self, height: _Optional[int] = ..., txhash: _Optional[str] = ..., codespace: _Optional[str] = ..., code: _Optional[int] = ..., data: _Optional[str] = ..., raw_log: _Optional[str] = ..., logs: _Optional[_Iterable[_Union[ABCIMessageLog, _Mapping]]] = ..., info: _Optional[str] = ..., gas_wanted: _Optional[int] = ..., gas_used: _Optional[int] = ..., tx: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., timestamp: _Optional[str] = ..., events: _Optional[_Iterable[_Union[_types_pb2.Event, _Mapping]]] = ...) -> None: ...

class ABCIMessageLog(_message.Message):
    __slots__ = ("msg_index", "log", "events")
    MSG_INDEX_FIELD_NUMBER: _ClassVar[int]
    LOG_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    msg_index: int
    log: str
    events: _containers.RepeatedCompositeFieldContainer[StringEvent]
    def __init__(self, msg_index: _Optional[int] = ..., log: _Optional[str] = ..., events: _Optional[_Iterable[_Union[StringEvent, _Mapping]]] = ...) -> None: ...

class StringEvent(_message.Message):
    __slots__ = ("type", "attributes")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    type: str
    attributes: _containers.RepeatedCompositeFieldContainer[Attribute]
    def __init__(self, type: _Optional[str] = ..., attributes: _Optional[_Iterable[_Union[Attribute, _Mapping]]] = ...) -> None: ...

class Attribute(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: str
    def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...

class GasInfo(_message.Message):
    __slots__ = ("gas_wanted", "gas_used")
    GAS_WANTED_FIELD_NUMBER: _ClassVar[int]
    GAS_USED_FIELD_NUMBER: _ClassVar[int]
    gas_wanted: int
    gas_used: int
    def __init__(self, gas_wanted: _Optional[int] = ..., gas_used: _Optional[int] = ...) -> None: ...

class Result(_message.Message):
    __slots__ = ("data", "log", "events", "msg_responses")
    DATA_FIELD_NUMBER: _ClassVar[int]
    LOG_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    MSG_RESPONSES_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    log: str
    events: _containers.RepeatedCompositeFieldContainer[_types_pb2.Event]
    msg_responses: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
    def __init__(self, data: _Optional[bytes] = ..., log: _Optional[str] = ..., events: _Optional[_Iterable[_Union[_types_pb2.Event, _Mapping]]] = ..., msg_responses: _Optional[_Iterable[_Union[_any_pb2.Any, _Mapping]]] = ...) -> None: ...

class SimulationResponse(_message.Message):
    __slots__ = ("gas_info", "result")
    GAS_INFO_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    gas_info: GasInfo
    result: Result
    def __init__(self, gas_info: _Optional[_Union[GasInfo, _Mapping]] = ..., result: _Optional[_Union[Result, _Mapping]] = ...) -> None: ...

class MsgData(_message.Message):
    __slots__ = ("msg_type", "data")
    MSG_TYPE_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    msg_type: str
    data: bytes
    def __init__(self, msg_type: _Optional[str] = ..., data: _Optional[bytes] = ...) -> None: ...

class TxMsgData(_message.Message):
    __slots__ = ("data", "msg_responses")
    DATA_FIELD_NUMBER: _ClassVar[int]
    MSG_RESPONSES_FIELD_NUMBER: _ClassVar[int]
    data: _containers.RepeatedCompositeFieldContainer[MsgData]
    msg_responses: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
    def __init__(self, data: _Optional[_Iterable[_Union[MsgData, _Mapping]]] = ..., msg_responses: _Optional[_Iterable[_Union[_any_pb2.Any, _Mapping]]] = ...) -> None: ...

class SearchTxsResult(_message.Message):
    __slots__ = ("total_count", "count", "page_number", "page_total", "limit", "txs")
    TOTAL_COUNT_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    PAGE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOTAL_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    TXS_FIELD_NUMBER: _ClassVar[int]
    total_count: int
    count: int
    page_number: int
    page_total: int
    limit: int
    txs: _containers.RepeatedCompositeFieldContainer[TxResponse]
    def __init__(self, total_count: _Optional[int] = ..., count: _Optional[int] = ..., page_number: _Optional[int] = ..., page_total: _Optional[int] = ..., limit: _Optional[int] = ..., txs: _Optional[_Iterable[_Union[TxResponse, _Mapping]]] = ...) -> None: ...

class SearchBlocksResult(_message.Message):
    __slots__ = ("total_count", "count", "page_number", "page_total", "limit", "blocks")
    TOTAL_COUNT_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    PAGE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOTAL_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    BLOCKS_FIELD_NUMBER: _ClassVar[int]
    total_count: int
    count: int
    page_number: int
    page_total: int
    limit: int
    blocks: _containers.RepeatedCompositeFieldContainer[_block_pb2.Block]
    def __init__(self, total_count: _Optional[int] = ..., count: _Optional[int] = ..., page_number: _Optional[int] = ..., page_total: _Optional[int] = ..., limit: _Optional[int] = ..., blocks: _Optional[_Iterable[_Union[_block_pb2.Block, _Mapping]]] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from v4_proto.cosmos.auth.v1beta1 import auth_pb2 as _auth_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgUpdateParams(_message.Message):
    __slots__ = ("authority", "params")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    params: _auth_pb2.Params
    def __init__(self, authority: _Optional[str] = ..., params: _Optional[_Union[_auth_pb2.Params, _Mapping]] = ...) -> None: ...

class MsgUpdateParamsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/affiliates/affiliates.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/affiliates/affiliates.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(dydxprotocol/affiliates/affiliates.proto\x12\x17\x64ydxprotocol.affiliates\x1a\x14gogoproto/gogo.proto\"\xc4\x01\n\x0e\x41\x66\x66iliateTiers\x12\x41\n\x05tiers\x18\x01 \x03(\x0b\x32,.dydxprotocol.affiliates.AffiliateTiers.TierB\x04\xc8\xde\x1f\x00\x1ao\n\x04Tier\x12*\n\"req_referred_volume_quote_quantums\x18\x01 \x01(\x04\x12\x1e\n\x16req_staked_whole_coins\x18\x02 \x01(\r\x12\x1b\n\x13taker_fee_share_ppm\x18\x03 \x01(\r\"\x93\x01\n\x12\x41\x66\x66iliateWhitelist\x12\x45\n\x05tiers\x18\x01 \x03(\x0b\x32\x30.dydxprotocol.affiliates.AffiliateWhitelist.TierB\x04\xc8\xde\x1f\x00\x1a\x36\n\x04Tier\x12\x11\n\taddresses\x18\x01 \x03(\t\x12\x1b\n\x13taker_fee_share_ppm\x18\x02 \x01(\rB>Z<github.com/dydxprotocol/v4-chain/protocol/x/affiliates/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.affiliates.affiliates_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dydxprotocol/v4-chain/protocol/x/affiliates/types'
  _globals['_AFFILIATETIERS'].fields_by_name['tiers']._loaded_options = None
  _globals['_AFFILIATETIERS'].fields_by_name['tiers']._serialized_options = b'\310\336\037\000'
  _globals['_AFFILIATEWHITELIST'].fields_by_name['tiers']._loaded_options = None
  _globals['_AFFILIATEWHITELIST'].fields_by_name['tiers']._serialized_options = b'\310\336\037\000'
  _globals['_AFFILIATETIERS']._serialized_start=92
  _globals['_AFFILIATETIERS']._serialized_end=288
  _globals['_AFFILIATETIERS_TIER']._serialized_start=177
  _globals['_AFFILIATETIERS_TIER']._serialized_end=288
  _globals['_AFFILIATEWHITELIST']._serialized_start=291
  _globals['_AFFILIATEWHITELIST']._serialized_end=438
  _globals['_AFFILIATEWHITELIST_TIER']._serialized_start=384
  _globals['_AFFILIATEWHITELIST_TIER']._serialized_end=438
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/assets/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/assets/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from v4_proto.dydxprotocol.assets import asset_pb2 as dydxprotocol_dot_assets_dot_asset__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x64ydxprotocol/assets/query.proto\x12\x13\x64ydxprotocol.assets\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1f\x64ydxprotocol/assets/asset.proto\"\x1f\n\x11QueryAssetRequest\x12\n\n\x02id\x18\x01 \x01(\r\"E\n\x12QueryAssetResponse\x12/\n\x05\x61sset\x18\x01 \x01(\x0b\x32\x1a.dydxprotocol.assets.AssetB\x04\xc8\xde\x1f\x00\"S\n\x15QueryAllAssetsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x86\x01\n\x16QueryAllAssetsResponse\x12/\n\x05\x61sset\x18\x01 \x03(\x0b\x32\x1a.dydxprotocol.assets.AssetB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\x96\x02\n\x05Query\x12\x81\x01\n\x05\x41sset\x12&.dydxprotocol.assets.QueryAssetRequest\x1a\'.dydxprotocol.assets.QueryAssetResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/dydxprotocol/assets/asset/{id}\x12\x88\x01\n\tAllAssets\x12*.dydxprotocol.assets.QueryAllAssetsRequest\x1a+.dydxprotocol.assets.QueryAllAssetsResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/dydxprotocol/assets/assetB:Z8github.com/dydxprotocol/v4-chain/protocol/x/assets/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.assets.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8github.com/dydxprotocol/v4-chain/protocol/x/assets/types'
  _globals['_QUERYASSETRESPONSE'].fields_by_name['asset']._loaded_options = None
  _globals['_QUERYASSETRESPONSE'].fields_by_name['asset']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYALLASSETSRESPONSE'].fields_by_name['asset']._loaded_options = None
  _globals['_QUERYALLASSETSRESPONSE'].fields_by_name['asset']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['Asset']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Asset']._serialized_options = b'\202\323\344\223\002!\022\037/dydxprotocol/assets/asset/{id}'
  _globals['_QUERY'].methods_by_name['AllAssets']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AllAssets']._serialized_options = b'\202\323\344\223\002\034\022\032/dydxprotocol/assets/asset'
  _globals['_QUERYASSETREQUEST']._serialized_start=185
  _globals['_QUERYASSETREQUEST']._serialized_end=216
  _globals['_QUERYASSETRESPONSE']._serialized_start=218
  _globals['_QUERYASSETRESPONSE']._serialized_end=287
  _globals['_QUERYALLASSETSREQUEST']._serialized_start=289
  _globals['_QUERYALLASSETSREQUEST']._serialized_end=372
  _globals['_QUERYALLASSETSRESPONSE']._serialized_start=375
  _globals['_QUERYALLASSETSRESPONSE']._serialized_end=509
  _globals['_QUERY']._serialized_start=512
  _globals['_QUERY']._serialized_end=790
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/indexer/shared/removal_reason.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/indexer/shared/removal_reason.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0dydxprotocol/indexer/shared/removal_reason.proto\x12\x1b\x64ydxprotocol.indexer.shared*\xf6\x05\n\x12OrderRemovalReason\x12$\n ORDER_REMOVAL_REASON_UNSPECIFIED\x10\x00\x12 \n\x1cORDER_REMOVAL_REASON_EXPIRED\x10\x01\x12&\n\"ORDER_REMOVAL_REASON_USER_CANCELED\x10\x02\x12,\n(ORDER_REMOVAL_REASON_UNDERCOLLATERALIZED\x10\x03\x12\'\n#ORDER_REMOVAL_REASON_INTERNAL_ERROR\x10\x04\x12)\n%ORDER_REMOVAL_REASON_SELF_TRADE_ERROR\x10\x05\x12:\n6ORDER_REMOVAL_REASON_POST_ONLY_WOULD_CROSS_MAKER_ORDER\x10\x06\x12?\n;ORDER_REMOVAL_REASON_IMMEDIATE_OR_CANCEL_WOULD_REST_ON_BOOK\x10\x07\x12<\n8ORDER_REMOVAL_REASON_FOK_ORDER_COULD_NOT_BE_FULLY_FULLED\x10\x08\x12+\n\'ORDER_REMOVAL_REASON_REDUCE_ONLY_RESIZE\x10\t\x12(\n$ORDER_REMOVAL_REASON_INDEXER_EXPIRED\x10\n\x12!\n\x1dORDER_REMOVAL_REASON_REPLACED\x10\x0b\x12%\n!ORDER_REMOVAL_REASON_FULLY_FILLED\x10\x0c\x12$\n ORDER_REMOVAL_REASON_EQUITY_TIER\x10\r\x12)\n%ORDER_REMOVAL_REASON_FINAL_SETTLEMENT\x10\x0e\x12\x41\n=ORDER_REMOVAL_REASON_VIOLATES_ISOLATED_SUBACCOUNT_CONSTRAINTS\x10\x0f\x42@Z>github.com/dydxprotocol/v4-chain/protocol/indexer/shared/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.indexer.shared.removal_reason_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z>github.com/dydxprotocol/v4-chain/protocol/indexer/shared/types'
  _globals['_ORDERREMOVALREASON']._serialized_start=82
  _globals['_ORDERREMOVALREASON']._serialized_end=840
# @@protoc_insertion_point(module_scope)



import datetime

from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UpdateMarketPricesRequest(_message.Message):
    __slots__ = ("market_price_updates",)
    MARKET_PRICE_UPDATES_FIELD_NUMBER: _ClassVar[int]
    market_price_updates: _containers.RepeatedCompositeFieldContainer[MarketPriceUpdate]
    def __init__(self, market_price_updates: _Optional[_Iterable[_Union[MarketPriceUpdate, _Mapping]]] = ...) -> None: ...

class UpdateMarketPricesResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ExchangePrice(_message.Message):
    __slots__ = ("exchange_id", "price", "last_update_time")
    EXCHANGE_ID_FIELD_NUMBER: _ClassVar[int]
    PRICE_FIELD_NUMBER: _ClassVar[int]
    LAST_UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    exchange_id: str
    price: int
    last_update_time: _timestamp_pb2.Timestamp
    def __init__(self, exchange_id: _Optional[str] = ..., price: _Optional[int] = ..., last_update_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class MarketPriceUpdate(_message.Message):
    __slots__ = ("market_id", "exchange_prices")
    MARKET_ID_FIELD_NUMBER: _ClassVar[int]
    EXCHANGE_PRICES_FIELD_NUMBER: _ClassVar[int]
    market_id: int
    exchange_prices: _containers.RepeatedCompositeFieldContainer[ExchangePrice]
    def __init__(self, market_id: _Optional[int] = ..., exchange_prices: _Optional[_Iterable[_Union[ExchangePrice, _Mapping]]] = ...) -> None: ...



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from v4_proto.dydxprotocol.vest import vest_entry_pb2 as _vest_entry_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgDeleteVestEntry(_message.Message):
    __slots__ = ("authority", "vester_account")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    VESTER_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    authority: str
    vester_account: str
    def __init__(self, authority: _Optional[str] = ..., vester_account: _Optional[str] = ...) -> None: ...

class MsgDeleteVestEntryResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgSetVestEntry(_message.Message):
    __slots__ = ("authority", "entry")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    ENTRY_FIELD_NUMBER: _ClassVar[int]
    authority: str
    entry: _vest_entry_pb2.VestEntry
    def __init__(self, authority: _Optional[str] = ..., entry: _Optional[_Union[_vest_entry_pb2.VestEntry, _Mapping]] = ...) -> None: ...

class MsgSetVestEntryResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/ratelimit/capacity.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/ratelimit/capacity.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.ratelimit import limit_params_pb2 as dydxprotocol_dot_ratelimit_dot_limit__params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%dydxprotocol/ratelimit/capacity.proto\x12\x16\x64ydxprotocol.ratelimit\x1a\x14gogoproto/gogo.proto\x1a)dydxprotocol/ratelimit/limit_params.proto\"\x7f\n\rDenomCapacity\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12_\n\rcapacity_list\x18\x02 \x03(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\"\xa5\x01\n\x0fLimiterCapacity\x12\x36\n\x07limiter\x18\x01 \x01(\x0b\x32\x1f.dydxprotocol.ratelimit.LimiterB\x04\xc8\xde\x1f\x00\x12Z\n\x08\x63\x61pacity\x18\x02 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableIntB=Z;github.com/dydxprotocol/v4-chain/protocol/x/ratelimit/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.ratelimit.capacity_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z;github.com/dydxprotocol/v4-chain/protocol/x/ratelimit/types'
  _globals['_DENOMCAPACITY'].fields_by_name['capacity_list']._loaded_options = None
  _globals['_DENOMCAPACITY'].fields_by_name['capacity_list']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_LIMITERCAPACITY'].fields_by_name['limiter']._loaded_options = None
  _globals['_LIMITERCAPACITY'].fields_by_name['limiter']._serialized_options = b'\310\336\037\000'
  _globals['_LIMITERCAPACITY'].fields_by_name['capacity']._loaded_options = None
  _globals['_LIMITERCAPACITY'].fields_by_name['capacity']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_DENOMCAPACITY']._serialized_start=130
  _globals['_DENOMCAPACITY']._serialized_end=257
  _globals['_LIMITERCAPACITY']._serialized_start=260
  _globals['_LIMITERCAPACITY']._serialized_end=425
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/affiliates/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/affiliates/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.affiliates import affiliates_pb2 as dydxprotocol_dot_affiliates_dot_affiliates__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#dydxprotocol/affiliates/query.proto\x12\x17\x64ydxprotocol.affiliates\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a(dydxprotocol/affiliates/affiliates.proto\x1a\x1cgoogle/api/annotations.proto\"A\n\x14\x41\x66\x66iliateInfoRequest\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"\x98\x02\n\x15\x41\x66\x66iliateInfoResponse\x12\x16\n\x0eis_whitelisted\x18\x01 \x01(\x08\x12\x0c\n\x04tier\x18\x02 \x01(\r\x12\x15\n\rfee_share_ppm\x18\x03 \x01(\r\x12\x61\n\x0freferred_volume\x18\x04 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12_\n\rstaked_amount\x18\x05 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\">\n\x11ReferredByRequest\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"I\n\x12ReferredByResponse\x12\x33\n\x11\x61\x66\x66iliate_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"\x1a\n\x18\x41llAffiliateTiersRequest\"Y\n\x19\x41llAffiliateTiersResponse\x12<\n\x05tiers\x18\x01 \x01(\x0b\x32\'.dydxprotocol.affiliates.AffiliateTiersB\x04\xc8\xde\x1f\x00\"\x1b\n\x19\x41\x66\x66iliateWhitelistRequest\"b\n\x1a\x41\x66\x66iliateWhitelistResponse\x12\x44\n\twhitelist\x18\x01 \x01(\x0b\x32+.dydxprotocol.affiliates.AffiliateWhitelistB\x04\xc8\xde\x1f\x00\x32\xbc\x05\n\x05Query\x12\xa9\x01\n\rAffiliateInfo\x12-.dydxprotocol.affiliates.AffiliateInfoRequest\x1a..dydxprotocol.affiliates.AffiliateInfoResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/dydxprotocol/affiliates/affiliate_info/{address}\x12\x9d\x01\n\nReferredBy\x12*.dydxprotocol.affiliates.ReferredByRequest\x1a+.dydxprotocol.affiliates.ReferredByResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./dydxprotocol/affiliates/referred_by/{address}\x12\xb0\x01\n\x11\x41llAffiliateTiers\x12\x31.dydxprotocol.affiliates.AllAffiliateTiersRequest\x1a\x32.dydxprotocol.affiliates.AllAffiliateTiersResponse\"4\x82\xd3\xe4\x93\x02.\x12,/dydxprotocol/affiliates/all_affiliate_tiers\x12\xb3\x01\n\x12\x41\x66\x66iliateWhitelist\x12\x32.dydxprotocol.affiliates.AffiliateWhitelistRequest\x1a\x33.dydxprotocol.affiliates.AffiliateWhitelistResponse\"4\x82\xd3\xe4\x93\x02.\x12,/dydxprotocol/affiliates/affiliate_whitelistB>Z<github.com/dydxprotocol/v4-chain/protocol/x/affiliates/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.affiliates.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dydxprotocol/v4-chain/protocol/x/affiliates/types'
  _globals['_AFFILIATEINFOREQUEST'].fields_by_name['address']._loaded_options = None
  _globals['_AFFILIATEINFOREQUEST'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_AFFILIATEINFORESPONSE'].fields_by_name['referred_volume']._loaded_options = None
  _globals['_AFFILIATEINFORESPONSE'].fields_by_name['referred_volume']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_AFFILIATEINFORESPONSE'].fields_by_name['staked_amount']._loaded_options = None
  _globals['_AFFILIATEINFORESPONSE'].fields_by_name['staked_amount']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_REFERREDBYREQUEST'].fields_by_name['address']._loaded_options = None
  _globals['_REFERREDBYREQUEST'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_REFERREDBYRESPONSE'].fields_by_name['affiliate_address']._loaded_options = None
  _globals['_REFERREDBYRESPONSE'].fields_by_name['affiliate_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_ALLAFFILIATETIERSRESPONSE'].fields_by_name['tiers']._loaded_options = None
  _globals['_ALLAFFILIATETIERSRESPONSE'].fields_by_name['tiers']._serialized_options = b'\310\336\037\000'
  _globals['_AFFILIATEWHITELISTRESPONSE'].fields_by_name['whitelist']._loaded_options = None
  _globals['_AFFILIATEWHITELISTRESPONSE'].fields_by_name['whitelist']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['AffiliateInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AffiliateInfo']._serialized_options = b'\202\323\344\223\0023\0221/dydxprotocol/affiliates/affiliate_info/{address}'
  _globals['_QUERY'].methods_by_name['ReferredBy']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ReferredBy']._serialized_options = b'\202\323\344\223\0020\022./dydxprotocol/affiliates/referred_by/{address}'
  _globals['_QUERY'].methods_by_name['AllAffiliateTiers']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AllAffiliateTiers']._serialized_options = b'\202\323\344\223\002.\022,/dydxprotocol/affiliates/all_affiliate_tiers'
  _globals['_QUERY'].methods_by_name['AffiliateWhitelist']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AffiliateWhitelist']._serialized_options = b'\202\323\344\223\002.\022,/dydxprotocol/affiliates/affiliate_whitelist'
  _globals['_AFFILIATEINFOREQUEST']._serialized_start=185
  _globals['_AFFILIATEINFOREQUEST']._serialized_end=250
  _globals['_AFFILIATEINFORESPONSE']._serialized_start=253
  _globals['_AFFILIATEINFORESPONSE']._serialized_end=533
  _globals['_REFERREDBYREQUEST']._serialized_start=535
  _globals['_REFERREDBYREQUEST']._serialized_end=597
  _globals['_REFERREDBYRESPONSE']._serialized_start=599
  _globals['_REFERREDBYRESPONSE']._serialized_end=672
  _globals['_ALLAFFILIATETIERSREQUEST']._serialized_start=674
  _globals['_ALLAFFILIATETIERSREQUEST']._serialized_end=700
  _globals['_ALLAFFILIATETIERSRESPONSE']._serialized_start=702
  _globals['_ALLAFFILIATETIERSRESPONSE']._serialized_end=791
  _globals['_AFFILIATEWHITELISTREQUEST']._serialized_start=793
  _globals['_AFFILIATEWHITELISTREQUEST']._serialized_end=820
  _globals['_AFFILIATEWHITELISTRESPONSE']._serialized_start=822
  _globals['_AFFILIATEWHITELISTRESPONSE']._serialized_end=920
  _globals['_QUERY']._serialized_start=923
  _globals['_QUERY']._serialized_end=1623
# @@protoc_insertion_point(module_scope)



import datetime

from v4_proto.cosmos.app.v1alpha1 import module_pb2 as _module_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Module(_message.Message):
    __slots__ = ("max_execution_period", "max_metadata_len")
    MAX_EXECUTION_PERIOD_FIELD_NUMBER: _ClassVar[int]
    MAX_METADATA_LEN_FIELD_NUMBER: _ClassVar[int]
    max_execution_period: _duration_pb2.Duration
    max_metadata_len: int
    def __init__(self, max_execution_period: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., max_metadata_len: _Optional[int] = ...) -> None: ...



from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DelayedMessage(_message.Message):
    __slots__ = ("id", "msg", "block_height")
    ID_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    id: int
    msg: _any_pb2.Any
    block_height: int
    def __init__(self, id: _Optional[int] = ..., msg: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., block_height: _Optional[int] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EquityTierLimitConfiguration(_message.Message):
    __slots__ = ("short_term_order_equity_tiers", "stateful_order_equity_tiers")
    SHORT_TERM_ORDER_EQUITY_TIERS_FIELD_NUMBER: _ClassVar[int]
    STATEFUL_ORDER_EQUITY_TIERS_FIELD_NUMBER: _ClassVar[int]
    short_term_order_equity_tiers: _containers.RepeatedCompositeFieldContainer[EquityTierLimit]
    stateful_order_equity_tiers: _containers.RepeatedCompositeFieldContainer[EquityTierLimit]
    def __init__(self, short_term_order_equity_tiers: _Optional[_Iterable[_Union[EquityTierLimit, _Mapping]]] = ..., stateful_order_equity_tiers: _Optional[_Iterable[_Union[EquityTierLimit, _Mapping]]] = ...) -> None: ...

class EquityTierLimit(_message.Message):
    __slots__ = ("usd_tnc_required", "limit")
    USD_TNC_REQUIRED_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    usd_tnc_required: bytes
    limit: int
    def __init__(self, usd_tnc_required: _Optional[bytes] = ..., limit: _Optional[int] = ...) -> None: ...



from v4_proto.dydxprotocol.delaymsg import delayed_message_pb2 as _delayed_message_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("delayed_messages", "next_delayed_message_id")
    DELAYED_MESSAGES_FIELD_NUMBER: _ClassVar[int]
    NEXT_DELAYED_MESSAGE_ID_FIELD_NUMBER: _ClassVar[int]
    delayed_messages: _containers.RepeatedCompositeFieldContainer[_delayed_message_pb2.DelayedMessage]
    next_delayed_message_id: int
    def __init__(self, delayed_messages: _Optional[_Iterable[_Union[_delayed_message_pb2.DelayedMessage, _Mapping]]] = ..., next_delayed_message_id: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/revshare/tx.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/revshare/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.revshare import params_pb2 as dydxprotocol_dot_revshare_dot_params__pb2
from v4_proto.dydxprotocol.revshare import revshare_pb2 as dydxprotocol_dot_revshare_dot_revshare__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x64ydxprotocol/revshare/tx.proto\x12\x15\x64ydxprotocol.revshare\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x14gogoproto/gogo.proto\x1a\"dydxprotocol/revshare/params.proto\x1a$dydxprotocol/revshare/revshare.proto\"\xaa\x01\n\x1eMsgSetMarketMapperRevenueShare\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12K\n\x06params\x18\x02 \x01(\x0b\x32\x35.dydxprotocol.revshare.MarketMapperRevenueShareParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"(\n&MsgSetMarketMapperRevenueShareResponse\"\xc6\x01\n*MsgSetMarketMapperRevShareDetailsForMarket\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x11\n\tmarket_id\x18\x02 \x01(\r\x12H\n\x06params\x18\x03 \x01(\x0b\x32\x32.dydxprotocol.revshare.MarketMapperRevShareDetailsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"4\n2MsgSetMarketMapperRevShareDetailsForMarketResponse\"\xad\x01\n$MsgUpdateUnconditionalRevShareConfig\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12H\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x32.dydxprotocol.revshare.UnconditionalRevShareConfigB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\".\n,MsgUpdateUnconditionalRevShareConfigResponse\"\xaa\x01\n\x19MsgSetOrderRouterRevShare\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12P\n\x16order_router_rev_share\x18\x02 \x01(\x0b\x32*.dydxprotocol.revshare.OrderRouterRevShareB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"#\n!MsgSetOrderRouterRevShareResponse2\x84\x05\n\x03Msg\x12\x93\x01\n\x1bSetMarketMapperRevenueShare\x12\x35.dydxprotocol.revshare.MsgSetMarketMapperRevenueShare\x1a=.dydxprotocol.revshare.MsgSetMarketMapperRevenueShareResponse\x12\xb7\x01\n\'SetMarketMapperRevShareDetailsForMarket\x12\x41.dydxprotocol.revshare.MsgSetMarketMapperRevShareDetailsForMarket\x1aI.dydxprotocol.revshare.MsgSetMarketMapperRevShareDetailsForMarketResponse\x12\xa5\x01\n!UpdateUnconditionalRevShareConfig\x12;.dydxprotocol.revshare.MsgUpdateUnconditionalRevShareConfig\x1a\x43.dydxprotocol.revshare.MsgUpdateUnconditionalRevShareConfigResponse\x12\x84\x01\n\x16SetOrderRouterRevShare\x12\x30.dydxprotocol.revshare.MsgSetOrderRouterRevShare\x1a\x38.dydxprotocol.revshare.MsgSetOrderRouterRevShareResponseB<Z:github.com/dydxprotocol/v4-chain/protocol/x/revshare/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.revshare.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/dydxprotocol/v4-chain/protocol/x/revshare/types'
  _globals['_MSGSETMARKETMAPPERREVENUESHARE'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSETMARKETMAPPERREVENUESHARE'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETMARKETMAPPERREVENUESHARE'].fields_by_name['params']._loaded_options = None
  _globals['_MSGSETMARKETMAPPERREVENUESHARE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETMARKETMAPPERREVENUESHARE']._loaded_options = None
  _globals['_MSGSETMARKETMAPPERREVENUESHARE']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGSETMARKETMAPPERREVSHAREDETAILSFORMARKET'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSETMARKETMAPPERREVSHAREDETAILSFORMARKET'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETMARKETMAPPERREVSHAREDETAILSFORMARKET'].fields_by_name['params']._loaded_options = None
  _globals['_MSGSETMARKETMAPPERREVSHAREDETAILSFORMARKET'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETMARKETMAPPERREVSHAREDETAILSFORMARKET']._loaded_options = None
  _globals['_MSGSETMARKETMAPPERREVSHAREDETAILSFORMARKET']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUPDATEUNCONDITIONALREVSHARECONFIG'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEUNCONDITIONALREVSHARECONFIG'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEUNCONDITIONALREVSHARECONFIG'].fields_by_name['config']._loaded_options = None
  _globals['_MSGUPDATEUNCONDITIONALREVSHARECONFIG'].fields_by_name['config']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEUNCONDITIONALREVSHARECONFIG']._loaded_options = None
  _globals['_MSGUPDATEUNCONDITIONALREVSHARECONFIG']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGSETORDERROUTERREVSHARE'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSETORDERROUTERREVSHARE'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETORDERROUTERREVSHARE'].fields_by_name['order_router_rev_share']._loaded_options = None
  _globals['_MSGSETORDERROUTERREVSHARE'].fields_by_name['order_router_rev_share']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETORDERROUTERREVSHARE']._loaded_options = None
  _globals['_MSGSETORDERROUTERREVSHARE']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGSETMARKETMAPPERREVENUESHARE']._serialized_start=206
  _globals['_MSGSETMARKETMAPPERREVENUESHARE']._serialized_end=376
  _globals['_MSGSETMARKETMAPPERREVENUESHARERESPONSE']._serialized_start=378
  _globals['_MSGSETMARKETMAPPERREVENUESHARERESPONSE']._serialized_end=418
  _globals['_MSGSETMARKETMAPPERREVSHAREDETAILSFORMARKET']._serialized_start=421
  _globals['_MSGSETMARKETMAPPERREVSHAREDETAILSFORMARKET']._serialized_end=619
  _globals['_MSGSETMARKETMAPPERREVSHAREDETAILSFORMARKETRESPONSE']._serialized_start=621
  _globals['_MSGSETMARKETMAPPERREVSHAREDETAILSFORMARKETRESPONSE']._serialized_end=673
  _globals['_MSGUPDATEUNCONDITIONALREVSHARECONFIG']._serialized_start=676
  _globals['_MSGUPDATEUNCONDITIONALREVSHARECONFIG']._serialized_end=849
  _globals['_MSGUPDATEUNCONDITIONALREVSHARECONFIGRESPONSE']._serialized_start=851
  _globals['_MSGUPDATEUNCONDITIONALREVSHARECONFIGRESPONSE']._serialized_end=897
  _globals['_MSGSETORDERROUTERREVSHARE']._serialized_start=900
  _globals['_MSGSETORDERROUTERREVSHARE']._serialized_end=1070
  _globals['_MSGSETORDERROUTERREVSHARERESPONSE']._serialized_start=1072
  _globals['_MSGSETORDERROUTERREVSHARERESPONSE']._serialized_end=1107
  _globals['_MSG']._serialized_start=1110
  _globals['_MSG']._serialized_end=1754
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AffiliateTiers(_message.Message):
    __slots__ = ("tiers",)
    class Tier(_message.Message):
        __slots__ = ("req_referred_volume_quote_quantums", "req_staked_whole_coins", "taker_fee_share_ppm")
        REQ_REFERRED_VOLUME_QUOTE_QUANTUMS_FIELD_NUMBER: _ClassVar[int]
        REQ_STAKED_WHOLE_COINS_FIELD_NUMBER: _ClassVar[int]
        TAKER_FEE_SHARE_PPM_FIELD_NUMBER: _ClassVar[int]
        req_referred_volume_quote_quantums: int
        req_staked_whole_coins: int
        taker_fee_share_ppm: int
        def __init__(self, req_referred_volume_quote_quantums: _Optional[int] = ..., req_staked_whole_coins: _Optional[int] = ..., taker_fee_share_ppm: _Optional[int] = ...) -> None: ...
    TIERS_FIELD_NUMBER: _ClassVar[int]
    tiers: _containers.RepeatedCompositeFieldContainer[AffiliateTiers.Tier]
    def __init__(self, tiers: _Optional[_Iterable[_Union[AffiliateTiers.Tier, _Mapping]]] = ...) -> None: ...

class AffiliateWhitelist(_message.Message):
    __slots__ = ("tiers",)
    class Tier(_message.Message):
        __slots__ = ("addresses", "taker_fee_share_ppm")
        ADDRESSES_FIELD_NUMBER: _ClassVar[int]
        TAKER_FEE_SHARE_PPM_FIELD_NUMBER: _ClassVar[int]
        addresses: _containers.RepeatedScalarFieldContainer[str]
        taker_fee_share_ppm: int
        def __init__(self, addresses: _Optional[_Iterable[str]] = ..., taker_fee_share_ppm: _Optional[int] = ...) -> None: ...
    TIERS_FIELD_NUMBER: _ClassVar[int]
    tiers: _containers.RepeatedCompositeFieldContainer[AffiliateWhitelist.Tier]
    def __init__(self, tiers: _Optional[_Iterable[_Union[AffiliateWhitelist.Tier, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/prices/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/prices/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from v4_proto.dydxprotocol.prices import market_param_pb2 as dydxprotocol_dot_prices_dot_market__param__pb2
from v4_proto.dydxprotocol.prices import market_price_pb2 as dydxprotocol_dot_prices_dot_market__price__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x64ydxprotocol/prices/query.proto\x12\x13\x64ydxprotocol.prices\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a&dydxprotocol/prices/market_param.proto\x1a&dydxprotocol/prices/market_price.proto\"%\n\x17QueryMarketPriceRequest\x12\n\n\x02id\x18\x01 \x01(\r\"X\n\x18QueryMarketPriceResponse\x12<\n\x0cmarket_price\x18\x01 \x01(\x0b\x32 .dydxprotocol.prices.MarketPriceB\x04\xc8\xde\x1f\x00\"Y\n\x1bQueryAllMarketPricesRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x9a\x01\n\x1cQueryAllMarketPricesResponse\x12=\n\rmarket_prices\x18\x01 \x03(\x0b\x32 .dydxprotocol.prices.MarketPriceB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"%\n\x17QueryMarketParamRequest\x12\n\n\x02id\x18\x01 \x01(\r\"X\n\x18QueryMarketParamResponse\x12<\n\x0cmarket_param\x18\x01 \x01(\x0b\x32 .dydxprotocol.prices.MarketParamB\x04\xc8\xde\x1f\x00\"Y\n\x1bQueryAllMarketParamsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x9a\x01\n\x1cQueryAllMarketParamsResponse\x12=\n\rmarket_params\x18\x01 \x03(\x0b\x32 .dydxprotocol.prices.MarketParamB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x1a\n\x18QueryNextMarketIdRequest\"3\n\x19QueryNextMarketIdResponse\x12\x16\n\x0enext_market_id\x18\x01 \x01(\r2\x9c\x06\n\x05Query\x12\x94\x01\n\x0bMarketPrice\x12,.dydxprotocol.prices.QueryMarketPriceRequest\x1a-.dydxprotocol.prices.QueryMarketPriceResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /dydxprotocol/prices/market/{id}\x12\x9b\x01\n\x0f\x41llMarketPrices\x12\x30.dydxprotocol.prices.QueryAllMarketPricesRequest\x1a\x31.dydxprotocol.prices.QueryAllMarketPricesResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/dydxprotocol/prices/market\x12\x9b\x01\n\x0bMarketParam\x12,.dydxprotocol.prices.QueryMarketParamRequest\x1a-.dydxprotocol.prices.QueryMarketParamResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/dydxprotocol/prices/params/market/{id}\x12\xa2\x01\n\x0f\x41llMarketParams\x12\x30.dydxprotocol.prices.QueryAllMarketParamsRequest\x1a\x31.dydxprotocol.prices.QueryAllMarketParamsResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/dydxprotocol/prices/params/market\x12\x9a\x01\n\x0cNextMarketId\x12-.dydxprotocol.prices.QueryNextMarketIdRequest\x1a..dydxprotocol.prices.QueryNextMarketIdResponse\"+\x82\xd3\xe4\x93\x02%\x12#/dydxprotocol/prices/next_market_idB:Z8github.com/dydxprotocol/v4-chain/protocol/x/prices/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.prices.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8github.com/dydxprotocol/v4-chain/protocol/x/prices/types'
  _globals['_QUERYMARKETPRICERESPONSE'].fields_by_name['market_price']._loaded_options = None
  _globals['_QUERYMARKETPRICERESPONSE'].fields_by_name['market_price']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYALLMARKETPRICESRESPONSE'].fields_by_name['market_prices']._loaded_options = None
  _globals['_QUERYALLMARKETPRICESRESPONSE'].fields_by_name['market_prices']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYMARKETPARAMRESPONSE'].fields_by_name['market_param']._loaded_options = None
  _globals['_QUERYMARKETPARAMRESPONSE'].fields_by_name['market_param']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYALLMARKETPARAMSRESPONSE'].fields_by_name['market_params']._loaded_options = None
  _globals['_QUERYALLMARKETPARAMSRESPONSE'].fields_by_name['market_params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['MarketPrice']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MarketPrice']._serialized_options = b'\202\323\344\223\002\"\022 /dydxprotocol/prices/market/{id}'
  _globals['_QUERY'].methods_by_name['AllMarketPrices']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AllMarketPrices']._serialized_options = b'\202\323\344\223\002\035\022\033/dydxprotocol/prices/market'
  _globals['_QUERY'].methods_by_name['MarketParam']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MarketParam']._serialized_options = b'\202\323\344\223\002)\022\'/dydxprotocol/prices/params/market/{id}'
  _globals['_QUERY'].methods_by_name['AllMarketParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AllMarketParams']._serialized_options = b'\202\323\344\223\002$\022\"/dydxprotocol/prices/params/market'
  _globals['_QUERY'].methods_by_name['NextMarketId']._loaded_options = None
  _globals['_QUERY'].methods_by_name['NextMarketId']._serialized_options = b'\202\323\344\223\002%\022#/dydxprotocol/prices/next_market_id'
  _globals['_QUERYMARKETPRICEREQUEST']._serialized_start=232
  _globals['_QUERYMARKETPRICEREQUEST']._serialized_end=269
  _globals['_QUERYMARKETPRICERESPONSE']._serialized_start=271
  _globals['_QUERYMARKETPRICERESPONSE']._serialized_end=359
  _globals['_QUERYALLMARKETPRICESREQUEST']._serialized_start=361
  _globals['_QUERYALLMARKETPRICESREQUEST']._serialized_end=450
  _globals['_QUERYALLMARKETPRICESRESPONSE']._serialized_start=453
  _globals['_QUERYALLMARKETPRICESRESPONSE']._serialized_end=607
  _globals['_QUERYMARKETPARAMREQUEST']._serialized_start=609
  _globals['_QUERYMARKETPARAMREQUEST']._serialized_end=646
  _globals['_QUERYMARKETPARAMRESPONSE']._serialized_start=648
  _globals['_QUERYMARKETPARAMRESPONSE']._serialized_end=736
  _globals['_QUERYALLMARKETPARAMSREQUEST']._serialized_start=738
  _globals['_QUERYALLMARKETPARAMSREQUEST']._serialized_end=827
  _globals['_QUERYALLMARKETPARAMSRESPONSE']._serialized_start=830
  _globals['_QUERYALLMARKETPARAMSRESPONSE']._serialized_end=984
  _globals['_QUERYNEXTMARKETIDREQUEST']._serialized_start=986
  _globals['_QUERYNEXTMARKETIDREQUEST']._serialized_end=1012
  _globals['_QUERYNEXTMARKETIDRESPONSE']._serialized_start=1014
  _globals['_QUERYNEXTMARKETIDRESPONSE']._serialized_end=1065
  _globals['_QUERY']._serialized_start=1068
  _globals['_QUERY']._serialized_end=1864
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/app/v1alpha1/module.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/app/v1alpha1/module.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/app/v1alpha1/module.proto\x12\x13\x63osmos.app.v1alpha1\x1a google/protobuf/descriptor.proto\"\xa1\x01\n\x10ModuleDescriptor\x12\x11\n\tgo_import\x18\x01 \x01(\t\x12:\n\x0buse_package\x18\x02 \x03(\x0b\x32%.cosmos.app.v1alpha1.PackageReference\x12>\n\x10\x63\x61n_migrate_from\x18\x03 \x03(\x0b\x32$.cosmos.app.v1alpha1.MigrateFromInfo\"2\n\x10PackageReference\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08revision\x18\x02 \x01(\r\"!\n\x0fMigrateFromInfo\x12\x0e\n\x06module\x18\x01 \x01(\t:Y\n\x06module\x12\x1f.google.protobuf.MessageOptions\x18\x87\xe8\xa2\x1b \x01(\x0b\x32%.cosmos.app.v1alpha1.ModuleDescriptorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.app.v1alpha1.module_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MODULEDESCRIPTOR']._serialized_start=92
  _globals['_MODULEDESCRIPTOR']._serialized_end=253
  _globals['_PACKAGEREFERENCE']._serialized_start=255
  _globals['_PACKAGEREFERENCE']._serialized_end=305
  _globals['_MIGRATEFROMINFO']._serialized_start=307
  _globals['_MIGRATEFROMINFO']._serialized_end=340
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
MODULE_FIELD_NUMBER: _ClassVar[int]
module: _descriptor.FieldDescriptor

class ModuleDescriptor(_message.Message):
    __slots__ = ("go_import", "use_package", "can_migrate_from")
    GO_IMPORT_FIELD_NUMBER: _ClassVar[int]
    USE_PACKAGE_FIELD_NUMBER: _ClassVar[int]
    CAN_MIGRATE_FROM_FIELD_NUMBER: _ClassVar[int]
    go_import: str
    use_package: _containers.RepeatedCompositeFieldContainer[PackageReference]
    can_migrate_from: _containers.RepeatedCompositeFieldContainer[MigrateFromInfo]
    def __init__(self, go_import: _Optional[str] = ..., use_package: _Optional[_Iterable[_Union[PackageReference, _Mapping]]] = ..., can_migrate_from: _Optional[_Iterable[_Union[MigrateFromInfo, _Mapping]]] = ...) -> None: ...

class PackageReference(_message.Message):
    __slots__ = ("name", "revision")
    NAME_FIELD_NUMBER: _ClassVar[int]
    REVISION_FIELD_NUMBER: _ClassVar[int]
    name: str
    revision: int
    def __init__(self, name: _Optional[str] = ..., revision: _Optional[int] = ...) -> None: ...

class MigrateFromInfo(_message.Message):
    __slots__ = ("module",)
    MODULE_FIELD_NUMBER: _ClassVar[int]
    module: str
    def __init__(self, module: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/upgrade/v1beta1/tx.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/upgrade/v1beta1/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.upgrade.v1beta1 import upgrade_pb2 as cosmos_dot_upgrade_dot_v1beta1_dot_upgrade__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmos/upgrade/v1beta1/tx.proto\x12\x16\x63osmos.upgrade.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a$cosmos/upgrade/v1beta1/upgrade.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\"\xaa\x01\n\x12MsgSoftwareUpgrade\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x35\n\x04plan\x18\x02 \x01(\x0b\x32\x1c.cosmos.upgrade.v1beta1.PlanB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:0\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\x1d\x63osmos-sdk/MsgSoftwareUpgrade\"\x1c\n\x1aMsgSoftwareUpgradeResponse\"o\n\x10MsgCancelUpgrade\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:.\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\x1b\x63osmos-sdk/MsgCancelUpgrade\"\x1a\n\x18MsgCancelUpgradeResponse2\xec\x01\n\x03Msg\x12q\n\x0fSoftwareUpgrade\x12*.cosmos.upgrade.v1beta1.MsgSoftwareUpgrade\x1a\x32.cosmos.upgrade.v1beta1.MsgSoftwareUpgradeResponse\x12k\n\rCancelUpgrade\x12(.cosmos.upgrade.v1beta1.MsgCancelUpgrade\x1a\x30.cosmos.upgrade.v1beta1.MsgCancelUpgradeResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x1eZ\x1c\x63osmossdk.io/x/upgrade/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.upgrade.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\034cosmossdk.io/x/upgrade/types'
  _globals['_MSGSOFTWAREUPGRADE'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSOFTWAREUPGRADE'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSOFTWAREUPGRADE'].fields_by_name['plan']._loaded_options = None
  _globals['_MSGSOFTWAREUPGRADE'].fields_by_name['plan']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGSOFTWAREUPGRADE']._loaded_options = None
  _globals['_MSGSOFTWAREUPGRADE']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\035cosmos-sdk/MsgSoftwareUpgrade'
  _globals['_MSGCANCELUPGRADE'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGCANCELUPGRADE'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCANCELUPGRADE']._loaded_options = None
  _globals['_MSGCANCELUPGRADE']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\033cosmos-sdk/MsgCancelUpgrade'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGSOFTWAREUPGRADE']._serialized_start=191
  _globals['_MSGSOFTWAREUPGRADE']._serialized_end=361
  _globals['_MSGSOFTWAREUPGRADERESPONSE']._serialized_start=363
  _globals['_MSGSOFTWAREUPGRADERESPONSE']._serialized_end=391
  _globals['_MSGCANCELUPGRADE']._serialized_start=393
  _globals['_MSGCANCELUPGRADE']._serialized_end=504
  _globals['_MSGCANCELUPGRADERESPONSE']._serialized_start=506
  _globals['_MSGCANCELUPGRADERESPONSE']._serialized_end=532
  _globals['_MSG']._serialized_start=535
  _globals['_MSG']._serialized_end=771
# @@protoc_insertion_point(module_scope)



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class MsgSlashValidator(_message.Message):
    __slots__ = ("authority", "validator_address", "infraction_height", "tokens_at_infraction_height", "slash_factor")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    INFRACTION_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TOKENS_AT_INFRACTION_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    SLASH_FACTOR_FIELD_NUMBER: _ClassVar[int]
    authority: str
    validator_address: str
    infraction_height: int
    tokens_at_infraction_height: bytes
    slash_factor: str
    def __init__(self, authority: _Optional[str] = ..., validator_address: _Optional[str] = ..., infraction_height: _Optional[int] = ..., tokens_at_infraction_height: _Optional[bytes] = ..., slash_factor: _Optional[str] = ...) -> None: ...

class MsgSlashValidatorResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class MarketMapperRevenueShareParams(_message.Message):
    __slots__ = ("address", "revenue_share_ppm", "valid_days")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    REVENUE_SHARE_PPM_FIELD_NUMBER: _ClassVar[int]
    VALID_DAYS_FIELD_NUMBER: _ClassVar[int]
    address: str
    revenue_share_ppm: int
    valid_days: int
    def __init__(self, address: _Optional[str] = ..., revenue_share_ppm: _Optional[int] = ..., valid_days: _Optional[int] = ...) -> None: ...



from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.cosmos.slashing.v1beta1 import slashing_pb2 as _slashing_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryParamsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ("params",)
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _slashing_pb2.Params
    def __init__(self, params: _Optional[_Union[_slashing_pb2.Params, _Mapping]] = ...) -> None: ...

class QuerySigningInfoRequest(_message.Message):
    __slots__ = ("cons_address",)
    CONS_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    cons_address: str
    def __init__(self, cons_address: _Optional[str] = ...) -> None: ...

class QuerySigningInfoResponse(_message.Message):
    __slots__ = ("val_signing_info",)
    VAL_SIGNING_INFO_FIELD_NUMBER: _ClassVar[int]
    val_signing_info: _slashing_pb2.ValidatorSigningInfo
    def __init__(self, val_signing_info: _Optional[_Union[_slashing_pb2.ValidatorSigningInfo, _Mapping]] = ...) -> None: ...

class QuerySigningInfosRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QuerySigningInfosResponse(_message.Message):
    __slots__ = ("info", "pagination")
    INFO_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    info: _containers.RepeatedCompositeFieldContainer[_slashing_pb2.ValidatorSigningInfo]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, info: _Optional[_Iterable[_Union[_slashing_pb2.ValidatorSigningInfo, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PerpetualMarketType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PERPETUAL_MARKET_TYPE_UNSPECIFIED: _ClassVar[PerpetualMarketType]
    PERPETUAL_MARKET_TYPE_CROSS: _ClassVar[PerpetualMarketType]
    PERPETUAL_MARKET_TYPE_ISOLATED: _ClassVar[PerpetualMarketType]
PERPETUAL_MARKET_TYPE_UNSPECIFIED: PerpetualMarketType
PERPETUAL_MARKET_TYPE_CROSS: PerpetualMarketType
PERPETUAL_MARKET_TYPE_ISOLATED: PerpetualMarketType

class Perpetual(_message.Message):
    __slots__ = ("params", "funding_index", "open_interest")
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    FUNDING_INDEX_FIELD_NUMBER: _ClassVar[int]
    OPEN_INTEREST_FIELD_NUMBER: _ClassVar[int]
    params: PerpetualParams
    funding_index: bytes
    open_interest: bytes
    def __init__(self, params: _Optional[_Union[PerpetualParams, _Mapping]] = ..., funding_index: _Optional[bytes] = ..., open_interest: _Optional[bytes] = ...) -> None: ...

class PerpetualParams(_message.Message):
    __slots__ = ("id", "ticker", "market_id", "atomic_resolution", "default_funding_ppm", "liquidity_tier", "market_type")
    ID_FIELD_NUMBER: _ClassVar[int]
    TICKER_FIELD_NUMBER: _ClassVar[int]
    MARKET_ID_FIELD_NUMBER: _ClassVar[int]
    ATOMIC_RESOLUTION_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_FUNDING_PPM_FIELD_NUMBER: _ClassVar[int]
    LIQUIDITY_TIER_FIELD_NUMBER: _ClassVar[int]
    MARKET_TYPE_FIELD_NUMBER: _ClassVar[int]
    id: int
    ticker: str
    market_id: int
    atomic_resolution: int
    default_funding_ppm: int
    liquidity_tier: int
    market_type: PerpetualMarketType
    def __init__(self, id: _Optional[int] = ..., ticker: _Optional[str] = ..., market_id: _Optional[int] = ..., atomic_resolution: _Optional[int] = ..., default_funding_ppm: _Optional[int] = ..., liquidity_tier: _Optional[int] = ..., market_type: _Optional[_Union[PerpetualMarketType, str]] = ...) -> None: ...

class MarketPremiums(_message.Message):
    __slots__ = ("perpetual_id", "premiums")
    PERPETUAL_ID_FIELD_NUMBER: _ClassVar[int]
    PREMIUMS_FIELD_NUMBER: _ClassVar[int]
    perpetual_id: int
    premiums: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, perpetual_id: _Optional[int] = ..., premiums: _Optional[_Iterable[int]] = ...) -> None: ...

class PremiumStore(_message.Message):
    __slots__ = ("all_market_premiums", "num_premiums")
    ALL_MARKET_PREMIUMS_FIELD_NUMBER: _ClassVar[int]
    NUM_PREMIUMS_FIELD_NUMBER: _ClassVar[int]
    all_market_premiums: _containers.RepeatedCompositeFieldContainer[MarketPremiums]
    num_premiums: int
    def __init__(self, all_market_premiums: _Optional[_Iterable[_Union[MarketPremiums, _Mapping]]] = ..., num_premiums: _Optional[int] = ...) -> None: ...

class LiquidityTier(_message.Message):
    __slots__ = ("id", "name", "initial_margin_ppm", "maintenance_fraction_ppm", "base_position_notional", "impact_notional", "open_interest_lower_cap", "open_interest_upper_cap")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    INITIAL_MARGIN_PPM_FIELD_NUMBER: _ClassVar[int]
    MAINTENANCE_FRACTION_PPM_FIELD_NUMBER: _ClassVar[int]
    BASE_POSITION_NOTIONAL_FIELD_NUMBER: _ClassVar[int]
    IMPACT_NOTIONAL_FIELD_NUMBER: _ClassVar[int]
    OPEN_INTEREST_LOWER_CAP_FIELD_NUMBER: _ClassVar[int]
    OPEN_INTEREST_UPPER_CAP_FIELD_NUMBER: _ClassVar[int]
    id: int
    name: str
    initial_margin_ppm: int
    maintenance_fraction_ppm: int
    base_position_notional: int
    impact_notional: int
    open_interest_lower_cap: int
    open_interest_upper_cap: int
    def __init__(self, id: _Optional[int] = ..., name: _Optional[str] = ..., initial_margin_ppm: _Optional[int] = ..., maintenance_fraction_ppm: _Optional[int] = ..., base_position_notional: _Optional[int] = ..., impact_notional: _Optional[int] = ..., open_interest_lower_cap: _Optional[int] = ..., open_interest_upper_cap: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/gov/v1/tx.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/gov/v1/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from v4_proto.cosmos.gov.v1 import gov_pb2 as cosmos_dot_gov_dot_v1_dot_gov__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x63osmos/gov/v1/tx.proto\x12\rcosmos.gov.v1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x17\x63osmos/gov/v1/gov.proto\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x19google/protobuf/any.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xdb\x02\n\x11MsgSubmitProposal\x12&\n\x08messages\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any\x12z\n\x0finitial_deposit\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01\x12*\n\x08proposer\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x10\n\x08metadata\x18\x04 \x01(\t\x12\r\n\x05title\x18\x05 \x01(\t\x12\x0f\n\x07summary\x18\x06 \x01(\t\x12\x11\n\texpedited\x18\x07 \x01(\x08:1\x82\xe7\xb0*\x08proposer\x8a\xe7\xb0*\x1f\x63osmos-sdk/v1/MsgSubmitProposal\"0\n\x19MsgSubmitProposalResponse\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\"\xa7\x01\n\x14MsgExecLegacyContent\x12\x45\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\x1e\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x12\x11\n\tauthority\x18\x02 \x01(\t:5\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\"cosmos-sdk/v1/MsgExecLegacyContent\"\x1e\n\x1cMsgExecLegacyContentResponse\"\xc0\x01\n\x07MsgVote\x12)\n\x0bproposal_id\x18\x01 \x01(\x04\x42\x14\xea\xde\x1f\x0bproposal_id\xa8\xe7\xb0*\x01\x12\'\n\x05voter\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12)\n\x06option\x18\x03 \x01(\x0e\x32\x19.cosmos.gov.v1.VoteOption\x12\x10\n\x08metadata\x18\x04 \x01(\t:$\x82\xe7\xb0*\x05voter\x8a\xe7\xb0*\x15\x63osmos-sdk/v1/MsgVote\"\x11\n\x0fMsgVoteResponse\"\xd9\x01\n\x0fMsgVoteWeighted\x12)\n\x0bproposal_id\x18\x01 \x01(\x04\x42\x14\xea\xde\x1f\x0bproposal_id\xa8\xe7\xb0*\x01\x12\'\n\x05voter\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x32\n\x07options\x18\x03 \x03(\x0b\x32!.cosmos.gov.v1.WeightedVoteOption\x12\x10\n\x08metadata\x18\x04 \x01(\t:,\x82\xe7\xb0*\x05voter\x8a\xe7\xb0*\x1d\x63osmos-sdk/v1/MsgVoteWeighted\"\x19\n\x17MsgVoteWeightedResponse\"\xc7\x01\n\nMsgDeposit\x12)\n\x0bproposal_id\x18\x01 \x01(\x04\x42\x14\xea\xde\x1f\x0bproposal_id\xa8\xe7\xb0*\x01\x12+\n\tdepositor\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x34\n\x06\x61mount\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:+\x82\xe7\xb0*\tdepositor\x8a\xe7\xb0*\x18\x63osmos-sdk/v1/MsgDeposit\"\x14\n\x12MsgDepositResponse\"\xa8\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x30\n\x06params\x18\x02 \x01(\x0b\x32\x15.cosmos.gov.v1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:6\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*#cosmos-sdk/x/gov/v1/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse\"t\n\x11MsgCancelProposal\x12$\n\x0bproposal_id\x18\x01 \x01(\x04\x42\x0f\xea\xde\x1f\x0bproposal_id\x12*\n\x08proposer\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:\r\x82\xe7\xb0*\x08proposer\"\x97\x01\n\x19MsgCancelProposalResponse\x12$\n\x0bproposal_id\x18\x01 \x01(\x04\x42\x0f\xea\xde\x1f\x0bproposal_id\x12;\n\rcanceled_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x17\n\x0f\x63\x61nceled_height\x18\x03 \x01(\x04\x32\xe8\x04\n\x03Msg\x12\\\n\x0eSubmitProposal\x12 .cosmos.gov.v1.MsgSubmitProposal\x1a(.cosmos.gov.v1.MsgSubmitProposalResponse\x12\x65\n\x11\x45xecLegacyContent\x12#.cosmos.gov.v1.MsgExecLegacyContent\x1a+.cosmos.gov.v1.MsgExecLegacyContentResponse\x12>\n\x04Vote\x12\x16.cosmos.gov.v1.MsgVote\x1a\x1e.cosmos.gov.v1.MsgVoteResponse\x12V\n\x0cVoteWeighted\x12\x1e.cosmos.gov.v1.MsgVoteWeighted\x1a&.cosmos.gov.v1.MsgVoteWeightedResponse\x12G\n\x07\x44\x65posit\x12\x19.cosmos.gov.v1.MsgDeposit\x1a!.cosmos.gov.v1.MsgDepositResponse\x12V\n\x0cUpdateParams\x12\x1e.cosmos.gov.v1.MsgUpdateParams\x1a&.cosmos.gov.v1.MsgUpdateParamsResponse\x12\\\n\x0e\x43\x61ncelProposal\x12 .cosmos.gov.v1.MsgCancelProposal\x1a(.cosmos.gov.v1.MsgCancelProposalResponse\x1a\x05\x80\xe7\xb0*\x01\x42-Z+github.com/cosmos/cosmos-sdk/x/gov/types/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.gov.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/cosmos/cosmos-sdk/x/gov/types/v1'
  _globals['_MSGSUBMITPROPOSAL'].fields_by_name['initial_deposit']._loaded_options = None
  _globals['_MSGSUBMITPROPOSAL'].fields_by_name['initial_deposit']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_MSGSUBMITPROPOSAL'].fields_by_name['proposer']._loaded_options = None
  _globals['_MSGSUBMITPROPOSAL'].fields_by_name['proposer']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSUBMITPROPOSAL']._loaded_options = None
  _globals['_MSGSUBMITPROPOSAL']._serialized_options = b'\202\347\260*\010proposer\212\347\260*\037cosmos-sdk/v1/MsgSubmitProposal'
  _globals['_MSGEXECLEGACYCONTENT'].fields_by_name['content']._loaded_options = None
  _globals['_MSGEXECLEGACYCONTENT'].fields_by_name['content']._serialized_options = b'\312\264-\032cosmos.gov.v1beta1.Content'
  _globals['_MSGEXECLEGACYCONTENT']._loaded_options = None
  _globals['_MSGEXECLEGACYCONTENT']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\"cosmos-sdk/v1/MsgExecLegacyContent'
  _globals['_MSGVOTE'].fields_by_name['proposal_id']._loaded_options = None
  _globals['_MSGVOTE'].fields_by_name['proposal_id']._serialized_options = b'\352\336\037\013proposal_id\250\347\260*\001'
  _globals['_MSGVOTE'].fields_by_name['voter']._loaded_options = None
  _globals['_MSGVOTE'].fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGVOTE']._loaded_options = None
  _globals['_MSGVOTE']._serialized_options = b'\202\347\260*\005voter\212\347\260*\025cosmos-sdk/v1/MsgVote'
  _globals['_MSGVOTEWEIGHTED'].fields_by_name['proposal_id']._loaded_options = None
  _globals['_MSGVOTEWEIGHTED'].fields_by_name['proposal_id']._serialized_options = b'\352\336\037\013proposal_id\250\347\260*\001'
  _globals['_MSGVOTEWEIGHTED'].fields_by_name['voter']._loaded_options = None
  _globals['_MSGVOTEWEIGHTED'].fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGVOTEWEIGHTED']._loaded_options = None
  _globals['_MSGVOTEWEIGHTED']._serialized_options = b'\202\347\260*\005voter\212\347\260*\035cosmos-sdk/v1/MsgVoteWeighted'
  _globals['_MSGDEPOSIT'].fields_by_name['proposal_id']._loaded_options = None
  _globals['_MSGDEPOSIT'].fields_by_name['proposal_id']._serialized_options = b'\352\336\037\013proposal_id\250\347\260*\001'
  _globals['_MSGDEPOSIT'].fields_by_name['depositor']._loaded_options = None
  _globals['_MSGDEPOSIT'].fields_by_name['depositor']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGDEPOSIT'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGDEPOSIT'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGDEPOSIT']._loaded_options = None
  _globals['_MSGDEPOSIT']._serialized_options = b'\202\347\260*\tdepositor\212\347\260*\030cosmos-sdk/v1/MsgDeposit'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*#cosmos-sdk/x/gov/v1/MsgUpdateParams'
  _globals['_MSGCANCELPROPOSAL'].fields_by_name['proposal_id']._loaded_options = None
  _globals['_MSGCANCELPROPOSAL'].fields_by_name['proposal_id']._serialized_options = b'\352\336\037\013proposal_id'
  _globals['_MSGCANCELPROPOSAL'].fields_by_name['proposer']._loaded_options = None
  _globals['_MSGCANCELPROPOSAL'].fields_by_name['proposer']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCANCELPROPOSAL']._loaded_options = None
  _globals['_MSGCANCELPROPOSAL']._serialized_options = b'\202\347\260*\010proposer'
  _globals['_MSGCANCELPROPOSALRESPONSE'].fields_by_name['proposal_id']._loaded_options = None
  _globals['_MSGCANCELPROPOSALRESPONSE'].fields_by_name['proposal_id']._serialized_options = b'\352\336\037\013proposal_id'
  _globals['_MSGCANCELPROPOSALRESPONSE'].fields_by_name['canceled_time']._loaded_options = None
  _globals['_MSGCANCELPROPOSALRESPONSE'].fields_by_name['canceled_time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGSUBMITPROPOSAL']._serialized_start=252
  _globals['_MSGSUBMITPROPOSAL']._serialized_end=599
  _globals['_MSGSUBMITPROPOSALRESPONSE']._serialized_start=601
  _globals['_MSGSUBMITPROPOSALRESPONSE']._serialized_end=649
  _globals['_MSGEXECLEGACYCONTENT']._serialized_start=652
  _globals['_MSGEXECLEGACYCONTENT']._serialized_end=819
  _globals['_MSGEXECLEGACYCONTENTRESPONSE']._serialized_start=821
  _globals['_MSGEXECLEGACYCONTENTRESPONSE']._serialized_end=851
  _globals['_MSGVOTE']._serialized_start=854
  _globals['_MSGVOTE']._serialized_end=1046
  _globals['_MSGVOTERESPONSE']._serialized_start=1048
  _globals['_MSGVOTERESPONSE']._serialized_end=1065
  _globals['_MSGVOTEWEIGHTED']._serialized_start=1068
  _globals['_MSGVOTEWEIGHTED']._serialized_end=1285
  _globals['_MSGVOTEWEIGHTEDRESPONSE']._serialized_start=1287
  _globals['_MSGVOTEWEIGHTEDRESPONSE']._serialized_end=1312
  _globals['_MSGDEPOSIT']._serialized_start=1315
  _globals['_MSGDEPOSIT']._serialized_end=1514
  _globals['_MSGDEPOSITRESPONSE']._serialized_start=1516
  _globals['_MSGDEPOSITRESPONSE']._serialized_end=1536
  _globals['_MSGUPDATEPARAMS']._serialized_start=1539
  _globals['_MSGUPDATEPARAMS']._serialized_end=1707
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=1709
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=1734
  _globals['_MSGCANCELPROPOSAL']._serialized_start=1736
  _globals['_MSGCANCELPROPOSAL']._serialized_end=1852
  _globals['_MSGCANCELPROPOSALRESPONSE']._serialized_start=1855
  _globals['_MSGCANCELPROPOSALRESPONSE']._serialized_end=2006
  _globals['_MSG']._serialized_start=2009
  _globals['_MSG']._serialized_end=2625
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/affiliates/tx.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/affiliates/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.affiliates import affiliates_pb2 as dydxprotocol_dot_affiliates_dot_affiliates__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n dydxprotocol/affiliates/tx.proto\x12\x17\x64ydxprotocol.affiliates\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a(dydxprotocol/affiliates/affiliates.proto\x1a\x17\x63osmos/msg/v1/msg.proto\"\x84\x01\n\x14MsgRegisterAffiliate\x12)\n\x07referee\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12+\n\taffiliate\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:\x14\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x07referee\"\x1e\n\x1cMsgRegisterAffiliateResponse\"\x94\x01\n\x17MsgUpdateAffiliateTiers\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12<\n\x05tiers\x18\x02 \x01(\x0b\x32\'.dydxprotocol.affiliates.AffiliateTiersB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"!\n\x1fMsgUpdateAffiliateTiersResponse\"\xa0\x01\n\x1bMsgUpdateAffiliateWhitelist\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x44\n\twhitelist\x18\x02 \x01(\x0b\x32+.dydxprotocol.affiliates.AffiliateWhitelistB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"%\n#MsgUpdateAffiliateWhitelistResponse2\x96\x03\n\x03Msg\x12y\n\x11RegisterAffiliate\x12-.dydxprotocol.affiliates.MsgRegisterAffiliate\x1a\x35.dydxprotocol.affiliates.MsgRegisterAffiliateResponse\x12\x82\x01\n\x14UpdateAffiliateTiers\x12\x30.dydxprotocol.affiliates.MsgUpdateAffiliateTiers\x1a\x38.dydxprotocol.affiliates.MsgUpdateAffiliateTiersResponse\x12\x8e\x01\n\x18UpdateAffiliateWhitelist\x12\x34.dydxprotocol.affiliates.MsgUpdateAffiliateWhitelist\x1a<.dydxprotocol.affiliates.MsgUpdateAffiliateWhitelistResponseB>Z<github.com/dydxprotocol/v4-chain/protocol/x/affiliates/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.affiliates.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dydxprotocol/v4-chain/protocol/x/affiliates/types'
  _globals['_MSGREGISTERAFFILIATE'].fields_by_name['referee']._loaded_options = None
  _globals['_MSGREGISTERAFFILIATE'].fields_by_name['referee']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGREGISTERAFFILIATE'].fields_by_name['affiliate']._loaded_options = None
  _globals['_MSGREGISTERAFFILIATE'].fields_by_name['affiliate']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGREGISTERAFFILIATE']._loaded_options = None
  _globals['_MSGREGISTERAFFILIATE']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\007referee'
  _globals['_MSGUPDATEAFFILIATETIERS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEAFFILIATETIERS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEAFFILIATETIERS'].fields_by_name['tiers']._loaded_options = None
  _globals['_MSGUPDATEAFFILIATETIERS'].fields_by_name['tiers']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEAFFILIATETIERS']._loaded_options = None
  _globals['_MSGUPDATEAFFILIATETIERS']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUPDATEAFFILIATEWHITELIST'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEAFFILIATEWHITELIST'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEAFFILIATEWHITELIST'].fields_by_name['whitelist']._loaded_options = None
  _globals['_MSGUPDATEAFFILIATEWHITELIST'].fields_by_name['whitelist']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEAFFILIATEWHITELIST']._loaded_options = None
  _globals['_MSGUPDATEAFFILIATEWHITELIST']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGREGISTERAFFILIATE']._serialized_start=178
  _globals['_MSGREGISTERAFFILIATE']._serialized_end=310
  _globals['_MSGREGISTERAFFILIATERESPONSE']._serialized_start=312
  _globals['_MSGREGISTERAFFILIATERESPONSE']._serialized_end=342
  _globals['_MSGUPDATEAFFILIATETIERS']._serialized_start=345
  _globals['_MSGUPDATEAFFILIATETIERS']._serialized_end=493
  _globals['_MSGUPDATEAFFILIATETIERSRESPONSE']._serialized_start=495
  _globals['_MSGUPDATEAFFILIATETIERSRESPONSE']._serialized_end=528
  _globals['_MSGUPDATEAFFILIATEWHITELIST']._serialized_start=531
  _globals['_MSGUPDATEAFFILIATEWHITELIST']._serialized_end=691
  _globals['_MSGUPDATEAFFILIATEWHITELISTRESPONSE']._serialized_start=693
  _globals['_MSGUPDATEAFFILIATEWHITELISTRESPONSE']._serialized_end=730
  _globals['_MSG']._serialized_start=733
  _globals['_MSG']._serialized_end=1139
# @@protoc_insertion_point(module_scope)
